@@ -19,16 +19,16 @@ class StringPtr: public std::vector<std::string *>
 
         public:
             iterator &operator--();
-            iterator const operator--(int);
+            iterator operator--(int);
             iterator &operator++();
-            iterator &operator++(int);
+            iterator operator++(int);
             bool operator==(iterator const &other) const;
             bool operator!=(iterator const &other) const;
             int operator-(iterator const &rhs) const;
             std::string &operator*() const;
             bool operator<(iterator const &other) const;
-            iterator const operator+(int step) const;
-            iterator const operator-(int step) const;
+            iterator operator+(int step) const;
+            iterator operator-(int step) const;
             iterator &operator+=(int step); // increment over `n' steps
             iterator &operator-=(int step); // decrement over `n' steps
             std::string *operator->() const;// access the fields of the
@@ -61,7 +61,7 @@ inline StringPtr::iterator &StringPtr::iterator::operator--()
 }
 //=
 //POSTDEC
-inline StringPtr::iterator const StringPtr::iterator::operator--(int)
+inline StringPtr::iterator StringPtr::iterator::operator--(int)
 {
     return iterator(d_current--);
 }
@@ -74,7 +74,7 @@ inline StringPtr::iterator &StringPtr::iterator::operator++()
 }
 //=
 //POSTINC
-inline StringPtr::iterator const StringPtr::iterator::operator++(int)
+inline StringPtr::iterator StringPtr::iterator::operator++(int)
 {
     return iterator(d_current++);
 }
@@ -110,15 +110,13 @@ inline bool StringPtr::iterator::operator<(iterator const &other) const
 }
 //=
 //OPADD
-inline StringPtr::iterator const
-        StringPtr::iterator::operator+(int step) const
+inline StringPtr::iterator StringPtr::iterator::operator+(int step) const
 {
     return iterator(d_current + step);
 }
 //=
 //OP-
-inline StringPtr::iterator const
-       StringPtr::iterator::operator-(int step) const
+inline StringPtr::iterator StringPtr::iterator::operator-(int step) const
 {
     return iterator(d_current - step);
 }
